@@ -8,16 +8,16 @@
  FILE: gtkdialogs.c */
 #include "common.h"
 #include "gtkdialogs.h"
-static int answer = ANSWER_YES;
-static char tentry[MAX_ENTRY_LENGTH];
-static char fmask[MASK_LENGTH];
-static char*** ptr = NULL;
-static int row = 0;
-static int col = 0;
+static INT answer = ANSWER_YES;
+static CHAR tentry[MAX_ENTRY_LENGTH];
+static CHAR fmask[MASK_LENGTH];
+static CHAR*** ptr = NULL;
+static INT row = 0;
+static INT col = 0;
 
-int strhasdot(char* str)
+INT strhasdot(CHAR* str)
 {
- int l,i;
+ INT l,i;
  debug("%s:%d strhasdot(%s)",__FILE__,__LINE__,str);
  if (!str) return 0;
  l = strlen(str)-1;
@@ -30,17 +30,19 @@ int strhasdot(char* str)
  return 0;
 }
 
+
 void destroy_widget(GtkWidget* w)
 {
  debug("%s:%d destroy_widget()",__FILE__,__LINE__);
  if (GTK_IS_WIDGET(w)) gtk_widget_destroy(w);
 }
 
-int mask_match()
+
+INT mask_match()
 {
- char tmps[MAX_ENTRY_LENGTH];
- char tmpm[MASK_LENGTH];
- int i,j;
+ CHAR tmps[MAX_ENTRY_LENGTH];
+ CHAR tmpm[MASK_LENGTH];
+ INT i,j;
  debug("%s:%d mask_match()",__FILE__,__LINE__);
  strcpy(tmps, tentry);
  strcpy(tmpm, fmask);
@@ -98,7 +100,7 @@ void ok_fs(GtkWidget* w, gpointer d)
 }
 
 
-gint delete_event_proc()
+INT delete_event_proc()
 {
  debug("%s:%d delete_event_proc()",__FILE__,__LINE__);
  answer = ANSWER_NO;
@@ -108,7 +110,7 @@ gint delete_event_proc()
 }
 
 
-gint delete_combos_proc(GtkWidget* w, gpointer d)
+INT delete_combos_proc(GtkWidget* w, gpointer d)
 {
  debug("%s:%d delete_combos_proc()",__FILE__,__LINE__);
  answer = ANSWER_NO;
@@ -166,6 +168,7 @@ void yes_proc(GtkWidget* w, gpointer d)
  destroy_widget((GtkWidget*)(d));
 }
 
+
 void return_value(GtkWidget* w, gpointer ptr)
 {
  GtkAdjustment* adj;
@@ -173,7 +176,7 @@ void return_value(GtkWidget* w, gpointer ptr)
  car = (struct carrier*)ptr;
  debug("%s:%d return_value()",__FILE__,__LINE__);
  adj = gtk_range_get_adjustment(GTK_RANGE(&(GTK_SCALE(car->ptr)->range)));
- answer = (int)(adj->value);
+ answer = (INT)(adj->value);
  gtk_main_quit();
  destroy_widget(car->widget);
 }
@@ -189,10 +192,10 @@ void no_proc(GtkWidget* w, gpointer d)
 }
 
 
-char* gtk_dialog_getfile_printf(const char* mask, const char* fmt, ...)
+CHAR* gtk_dialog_getfile_printf(const CHAR* mask, const CHAR* fmt, ...)
 {
  va_list ap;
- char msg[MAX_MSG_LENGTH];
+ CHAR msg[MAX_MSG_LENGTH];
  debug("%s:%d gtk_dialog_getfile_printf(%s,%s)",__FILE__,__LINE__,mask,fmt);
  if (!fmt) return NULL;
  va_start(ap, fmt);
@@ -202,10 +205,10 @@ char* gtk_dialog_getfile_printf(const char* mask, const char* fmt, ...)
 }
 
 
-char* gtk_dialog_gettext_printf(const char* fmt, ...)
+CHAR* gtk_dialog_gettext_printf(const CHAR* fmt, ...)
 {
  va_list ap;
- char msg[MAX_MSG_LENGTH];
+ CHAR msg[MAX_MSG_LENGTH];
  debug("%s:%d gtk_dialog_gettext_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return NULL;
  va_start(ap, fmt);
@@ -215,10 +218,10 @@ char* gtk_dialog_gettext_printf(const char* fmt, ...)
 }
 
 
-char* gtk_dialog_gettext_big_printf(const char* fmt, ...)
+CHAR* gtk_dialog_gettext_big_printf(const CHAR* fmt, ...)
 {
  va_list ap;
- char msg[MAX_MSG_LENGTH];
+ CHAR msg[MAX_MSG_LENGTH];
  debug("%s:%d gtk_dialog_gettext_big_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return NULL;
  va_start(ap, fmt);
@@ -227,10 +230,11 @@ char* gtk_dialog_gettext_big_printf(const char* fmt, ...)
  return gtk_dialog_gettext_big(msg);
 }
 
-int gtk_dialog_getnum_printf(int a, int b, char* fmt, ...)
+
+INT gtk_dialog_getnum_printf(INT a, INT b, CHAR* fmt, ...)
 {
  va_list ap;
- char msg[MAX_MSG_LENGTH];
+ CHAR msg[MAX_MSG_LENGTH];
  debug("%s:%d gtk_dialog_getnum_printf(%d,%d,%s)",__FILE__,__LINE__,a,b,fmt);
  if (!fmt) return -1;
  va_start(ap, fmt);
@@ -239,12 +243,13 @@ int gtk_dialog_getnum_printf(int a, int b, char* fmt, ...)
  return gtk_dialog_getnum(a,b,msg);
 }
 
-int gtk_dialog_getnum(int ua, int ub, char* msg)
+
+INT gtk_dialog_getnum(INT ua, INT ub, CHAR* msg)
 {
  GtkWidget *scale, *box, *window, *button;
  GtkObject *adj;
  struct carrier* car;
- int a,b;
+ INT a,b;
  debug("%s:%d gtk_dialog_getnum(%d,%d,%s)",__FILE__,__LINE__,ua,ub,msg);
  a = (ua<=ub)?ua:ub;
  b = (ua>ub) ?ua:ub;
@@ -265,7 +270,7 @@ int gtk_dialog_getnum(int ua, int ub, char* msg)
  button = gtk_button_new_with_label("OK");
  car = (struct carrier*)malloc(sizeof(struct carrier));
  car->widget = window;
- car->ptr    = (void*)scale; 
+ car->ptr    = (void*)scale;
  gtk_signal_connect (GTK_OBJECT(window), "destroy",GTK_SIGNAL_FUNC(return_value),(gpointer)(car));
  gtk_signal_connect(GTK_OBJECT(button), "clicked",GTK_SIGNAL_FUNC(return_value),(gpointer)(car));
  gtk_widget_show(button);
@@ -277,7 +282,8 @@ int gtk_dialog_getnum(int ua, int ub, char* msg)
  return answer;
 }
 
-char* gtk_dialog_getfile(const char* mask, const char* question)
+
+CHAR* gtk_dialog_getfile(const CHAR* mask, const CHAR* question)
 {
  GtkWidget* filew, *flist;
  debug("%s:%d gtk_dialog_getfile(%s,%s)",__FILE__,__LINE__,mask,question);
@@ -300,7 +306,7 @@ char* gtk_dialog_getfile(const char* mask, const char* question)
 }
 
 
-char* gtk_dialog_gettext_big(const char* question)
+CHAR* gtk_dialog_gettext_big(const CHAR* question)
 {
  GtkWidget* dialog, *label, *button, *entry;
  debug("%s:%d gtk_dialog_gettext_big(%s)",__FILE__,__LINE__,question?question:"null");
@@ -330,7 +336,8 @@ char* gtk_dialog_gettext_big(const char* question)
  return tentry;
 }
 
-char* gtk_dialog_getpass(const char* question)
+
+CHAR* gtk_dialog_getpass(const CHAR* question)
 {
  GtkWidget* dialog, *label, *button, *entry;
  debug("%s:%d gtk_dialog_gettext(%s)",__FILE__,__LINE__,question?question:"null");
@@ -361,7 +368,8 @@ char* gtk_dialog_getpass(const char* question)
  return tentry;
 }
 
-char* gtk_dialog_gettext(const char* question)
+
+CHAR* gtk_dialog_gettext(const CHAR* question)
 {
  GtkWidget* dialog, *label, *button, *entry;
  debug("%s:%d gtk_dialog_gettext(%s)",__FILE__,__LINE__,question?question:"null");
@@ -392,10 +400,10 @@ char* gtk_dialog_gettext(const char* question)
 }
 
 
-void gtk_dialog_printf(const char* fmt, ...)
+void gtk_dialog_printf(const CHAR* fmt, ...)
 {
  va_list ap;
- char msg[MAX_MSG_LENGTH];
+ CHAR msg[MAX_MSG_LENGTH];
  debug("%s:%d gtk_dialog_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return ;
  va_start(ap, fmt);
@@ -406,10 +414,10 @@ void gtk_dialog_printf(const char* fmt, ...)
 }
 
 
-void gtk_dialog_printf_big_with_title(const char* title, const char* fmt, ...)
+void gtk_dialog_printf_big_with_title(const CHAR* title, const CHAR* fmt, ...)
 {
  GtkWidget* dialog, *label, *button;
- char msg[MAX_MSG_LENGTH];
+ CHAR msg[MAX_MSG_LENGTH];
  va_list ap;
  debug("%s:%d gtk_dialog_printf_big_with_title(%s,%s)",__FILE__,__LINE__,title?title:"null",fmt);
  if (!title) warn("title=NULL: %s:%d",__FILE__,__LINE__);
@@ -434,10 +442,10 @@ void gtk_dialog_printf_big_with_title(const char* title, const char* fmt, ...)
 }
 
 
-void gtk_dialog_printf_big(const char* fmt, ...)
+void gtk_dialog_printf_big(const CHAR* fmt, ...)
 {
  GtkWidget* dialog, *label, *button;
- char msg[MAX_MSG_LENGTH];
+ CHAR msg[MAX_MSG_LENGTH];
  va_list ap;
  debug("%s:%d gtk_dialog_big_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return ;
@@ -462,10 +470,10 @@ void gtk_dialog_printf_big(const char* fmt, ...)
 }
 
 
-void gtk_dialog_printf_with_title(const char* title, const char* fmt, ...)
+void gtk_dialog_printf_with_title(const CHAR* title, const CHAR* fmt, ...)
 {
  GtkWidget* dialog, *label, *button;
- char msg[MAX_MSG_LENGTH];
+ CHAR msg[MAX_MSG_LENGTH];
  va_list ap;
  debug("%s:%d gtk_dialog_printf_with_title(%s,%s)",__FILE__,__LINE__,title,fmt);
  if (!fmt) return;
@@ -490,7 +498,7 @@ void gtk_dialog_printf_with_title(const char* title, const char* fmt, ...)
 }
 
 
-void gtk_dialog_mbox(const char* title, const char* msg)
+void gtk_dialog_mbox(const CHAR* title, const CHAR* msg)
 {
  GtkWidget* dialog, *label, *button;
  debug("%s:%d gtk_dialog_mbox(%s,%s)",__FILE__,__LINE__,title,msg);
@@ -513,10 +521,10 @@ void gtk_dialog_mbox(const char* title, const char* msg)
 }
 
 
-int gtk_dialog_yes_no_printf(const char* fmt, ...)
+INT gtk_dialog_yes_no_printf(const CHAR* fmt, ...)
 {
  GtkWidget* dialog, *label, *button_yes, *button_no;
- char question[MAX_MSG_LENGTH];
+ CHAR question[MAX_MSG_LENGTH];
  va_list ap;
  debug("%s:%d gtk_dialog_yes_no_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return 0;
@@ -546,7 +554,7 @@ int gtk_dialog_yes_no_printf(const char* fmt, ...)
 }
 
 
-int gtk_dialog_with_2_buttons(const char* question, char* but1, char* but2)
+INT gtk_dialog_with_2_buttons(const CHAR* question, CHAR* but1, CHAR* but2)
 {
  GtkWidget* dialog, *label, *button_yes, *button_no;
  debug("%s:%d gtk_dialog_with_2_buttons()",__FILE__,__LINE__);
@@ -574,7 +582,7 @@ int gtk_dialog_with_2_buttons(const char* question, char* but1, char* but2)
 }
 
 
-int gtk_dialog_yes_no(const char* question)
+INT gtk_dialog_yes_no(const CHAR* question)
 {
  GtkWidget* dialog, *label, *button_yes, *button_no;
  debug("%s:%d gtk_dialog_yes_no(%s)",__FILE__,__LINE__,question);
@@ -602,10 +610,10 @@ int gtk_dialog_yes_no(const char* question)
 }
 
 
-int setup_combo(PGconn* c, GtkWidget* w, GtkWidget** cmb)
+INT setup_combo(PGconn* c, GtkWidget* w, GtkWidget** cmb)
 {
- char errstr[MAX_QUERY_LENGTH];
- int i;
+ CHAR errstr[MAX_QUERY_LENGTH];
+ INT i;
  GList* list;
  debug("%s:%d setup_combo()",__FILE__,__LINE__);
  list = NULL;
@@ -631,10 +639,10 @@ int setup_combo(PGconn* c, GtkWidget* w, GtkWidget** cmb)
 }
 
 
-char* gtk_dialog_getdbs(PGconn* connection, char* fmt, ...)
+CHAR* gtk_dialog_getdbs(PGconn* connection, CHAR* fmt, ...)
 {
  GtkWidget* dialog, *combo, *button, *label;
- char msg[MAX_MSG_LENGTH];
+ CHAR msg[MAX_MSG_LENGTH];
  va_list ap;
  debug("%s:%d gtk_dialog_getdbs(%s)",__FILE__,__LINE__,fmt);
  if (!connection || !fmt) error("gtk_getdbs, params: %s:%d", __FILE__,__LINE__);
