@@ -8,7 +8,6 @@
  FILE: mmsystem.c */
 #include "mmsystem.h"
 #include "common.h"
-
 struct dmem_list* dmlist= NULL;
 struct mem_list*  mlist = NULL;				/* ALWAYS INITIALIZE WITH NULL, OR WILL BE TROUBLE !!!! */
 
@@ -28,7 +27,7 @@ void add_to_special_memlist(struct mem_list** head, void* ptr)
  if (!newh) { fatal("smalloc failed!"); return; }
  newh->ptr   = ptr;
  newh->next  = *head;
- *head       = newh; 
+ *head       = newh;
 }
 
 
@@ -50,6 +49,7 @@ void print_special_memlist(struct mem_list* head)
 #endif
 }
 
+
 void del_from_special_memlist(struct mem_list** head, void* ptr)
 {
  struct mem_list *tmp, *prev;
@@ -77,6 +77,7 @@ void del_from_special_memlist(struct mem_list** head, void* ptr)
  fatal("SPECIAL_MEMLIST: No such pointer: %p", ptr);
 }
 
+
 void add_to_memlist(void* ptr)
 {
  struct mem_list* newh;
@@ -93,7 +94,7 @@ void add_to_memlist(void* ptr)
  if (!newh) { fatal("malloc mlist failed!"); return; }
  newh->ptr   = ptr;
  newh->next  = mlist;
- mlist       = newh; 
+ mlist       = newh;
 }
 
 
@@ -115,6 +116,7 @@ void print_memlist()
 #endif
 }
 
+
 void del_from_memlist(void* ptr)
 {
  struct mem_list *tmp, *prev;
@@ -142,6 +144,7 @@ void del_from_memlist(void* ptr)
  fatal("MEMLIST: No such pointer: %p", ptr);
 }
 
+
 void shred_memlist()
 {
 #ifdef NO_TRACE_MEM
@@ -161,6 +164,7 @@ void shred_memlist()
 #endif
 }
 
+
 void shred_special_memlist(struct mem_list** head)
 {
 #ifdef NO_TRACE_MEM
@@ -180,13 +184,15 @@ void shred_special_memlist(struct mem_list** head)
 #endif
 }
 
-void* mmalloc(int siz)
+
+void* mmalloc(INT siz)
 {
 #ifdef NO_TRACE_MEM
  return malloc(siz);
 #else
  void* ptr;
  sdebug("%s:%d mmalloc(%d)",__FILE__,__LINE__,siz);
+ if (siz==0) siz=sizeof(void*);		//FIXME strange
  if (siz<=0) fatal("mmalloc: want negative memory or zero memory: %d", siz);
  ptr = malloc(siz);
  if (!ptr) { gtk_dialog_printf("mmalloc failed!"); fatal("mmalloc failed"); return NULL; }
@@ -195,13 +201,15 @@ void* mmalloc(int siz)
 #endif
 }
 
-void* mrealloc(void* orig, int siz)
+
+void* mrealloc(void* orig, INT siz)
 {
 #ifdef NO_TRACE_MEM
  return realloc(orig, siz);
 #else
  void* ptr;
  sdebug("%s:%d mrealloc(%p,%d)",__FILE__,__LINE__,orig,siz);
+ if (siz==0) siz=sizeof(void*);		//FIXME strange
  if (siz<=0) fatal("mmalloc: want negative memory or zero memory: %d", siz);
  ptr = realloc(orig, siz);
  if (!ptr) { gtk_dialog_printf("mmalloc failed!"); fatal("mmalloc failed"); return NULL; }
@@ -211,6 +219,7 @@ void* mrealloc(void* orig, int siz)
 #endif
 }
 
+
 void mfree(void** ptr)
 {
 #ifdef NO_TRACE_MEM
@@ -223,13 +232,15 @@ void mfree(void** ptr)
 #endif
 }
 
-void* smalloc(struct mem_list** headp, int siz)
+
+void* smalloc(struct mem_list** headp, INT siz)
 {
 #ifdef NO_TRACE_MEM
  return malloc(siz);
 #else
  void* ptr;
  sdebug("%s:%d smalloc(%p,%d)",__FILE__,__LINE__,*headp,siz);
+ if (siz==0) siz=sizeof(void*);		//FIXME strange
  if (siz<=0) fatal("smalloc: want negative memory or zero memory: %p:%d", (void*)headp, siz);
  ptr = malloc(siz);
  if (!ptr) { gtk_dialog_printf("smalloc failed!"); fatal("smalloc failed"); return NULL; }
@@ -238,6 +249,7 @@ void* smalloc(struct mem_list** headp, int siz)
 #endif
 }
 
+
 void sfree(struct mem_list** headp, void** ptr)
 {
 #ifdef NO_TRACE_MEM
@@ -249,15 +261,17 @@ void sfree(struct mem_list** headp, void** ptr)
  *ptr = NULL;
 #endif
 }
+
 /* VERY DEBUG ONES... */
 
-void* dsmalloc(struct dmem_list** headp, int siz, char* file, int line)
+void* dsmalloc(struct dmem_list** headp, INT siz, CHAR* file, INT line)
 {
 #ifdef NO_TRACE_MEM
  return malloc(siz);
 #else
  void* ptr;
  sdebug("%s:%d dsmalloc(%p) called from %s:%d, want %d bytes",__FILE__,__LINE__, *headp,file,line,siz);
+ if (siz==0) siz=sizeof(void*);		//FIXME strange
  if (siz<=0) fatal("dsmalloc: want negative memory or zero memory: %p:%d, called from %s:%d", (void*)headp,siz,file,line);
  ptr = malloc(siz);
  if (!ptr) { gtk_dialog_printf("dsmalloc failed!"); fatal("dsmalloc failed"); return NULL; }
@@ -266,7 +280,8 @@ void* dsmalloc(struct dmem_list** headp, int siz, char* file, int line)
 #endif
 }
 
-void dsfree(struct dmem_list** headp, void** ptr, char* file, int line)
+
+void dsfree(struct dmem_list** headp, void** ptr, CHAR* file, INT line)
 {
 #ifdef NO_TRACE_MEM
  free(*ptr);
@@ -277,7 +292,9 @@ void dsfree(struct dmem_list** headp, void** ptr, char* file, int line)
  *ptr = NULL;
 #endif
 }
-void dshred_special_memlist(struct dmem_list** head, char* file, int line)
+
+
+void dshred_special_memlist(struct dmem_list** head, CHAR* file, INT line)
 {
 #ifdef NO_TRACE_MEM
  return ;
@@ -297,7 +314,8 @@ void dshred_special_memlist(struct dmem_list** head, char* file, int line)
 #endif
 }
 
-void dadd_to_special_memlist(struct dmem_list** head, void* ptr, char* file, int line, int size)
+
+void dadd_to_special_memlist(struct dmem_list** head, void* ptr, CHAR* file, INT line, INT size)
 {
  struct dmem_list* newh;
  sdebug("%s:%d dadd_to_special_memlist(%p,%p) called from <delegation> %s:%d, bytes: %d",__FILE__,__LINE__,*head, ptr, file,line,size);
@@ -319,10 +337,11 @@ void dadd_to_special_memlist(struct dmem_list** head, void* ptr, char* file, int
  newh->file = file;
  newh->line = line;
  newh->count = size;
- *head       = newh; 
+ *head       = newh;
 }
 
-void dprint_special_memlist(struct dmem_list* head, char* file, int line)
+
+void dprint_special_memlist(struct dmem_list* head, CHAR* file, INT line)
 {
 #ifdef NO_TRACE_MEM
  return;
@@ -340,7 +359,8 @@ void dprint_special_memlist(struct dmem_list* head, char* file, int line)
 #endif
 }
 
-void ddel_from_special_memlist(struct dmem_list** head, void* ptr, char* file, int line)
+
+void ddel_from_special_memlist(struct dmem_list** head, void* ptr, CHAR* file, INT line)
 {
  struct dmem_list *tmp, *prev;
  sdebug("%s:%d ddel_from_special_memlist(%p,%p) called from <delegation> %s:%d",__FILE__,__LINE__,*head,ptr,file,line);
@@ -369,13 +389,15 @@ void ddel_from_special_memlist(struct dmem_list** head, void* ptr, char* file, i
  fatal("DEBUG_SPECIAL_MEMLIST: No such pointer: %p", ptr);
 }
 
-void* dmmalloc(int siz, char* file, int line)
+
+void* dmmalloc(INT siz, CHAR* file, INT line)
 {
 #ifdef NO_TRACE_MEM
  return malloc(siz);
 #else
  void* ptr;
  sdebug("%s:%d dmmalloc() called from %s:%d, want %d bytes",__FILE__,__LINE__, file,line,siz);
+ if (siz==0) siz=sizeof(void*);		//FIXME strange
  if (siz<=0) fatal("dmmalloc: want negative memory or zero memory: %p:%d, called from %s:%d", (void*)dmlist,siz,file,line);
  ptr = malloc(siz);
  if (!ptr) { gtk_dialog_printf("dmmalloc failed!"); fatal("dmmalloc failed"); return NULL; }
@@ -384,13 +406,15 @@ void* dmmalloc(int siz, char* file, int line)
 #endif
 }
 
-void* dmrealloc(void* orig, int siz, char* file, int line)
+
+void* dmrealloc(void* orig, INT siz, CHAR* file, INT line)
 {
 #ifdef NO_TRACE_MEM
  return realloc(orig, siz);
 #else
  void* ptr;
  sdebug("%s:%d dmrealloc called from %s:%d, want %d bytes, at addres: %p",__FILE__,__LINE__, file,line,siz, orig);
+ if (siz==0) siz=sizeof(void*);		//FIXME strange
  if (siz<=0) fatal("dmrealloc: want negative memory or zero memory: %p:%d, called from %s:%d", (void*)dmlist,siz,file,line);
  ptr = realloc(orig, siz);
  if (!ptr) { gtk_dialog_printf("dmrealloc failed!"); fatal("dmrealloc failed"); return NULL; }
@@ -400,7 +424,8 @@ void* dmrealloc(void* orig, int siz, char* file, int line)
 #endif
 }
 
-void dmfree(void** ptr, char* file, int line)
+
+void dmfree(void** ptr, CHAR* file, INT line)
 {
 #ifdef NO_TRACE_MEM
  free(*ptr);
@@ -411,7 +436,9 @@ void dmfree(void** ptr, char* file, int line)
  *ptr = NULL;
 #endif
 }
-void dshred_memlist(char* file, int line)
+
+
+void dshred_memlist(CHAR* file, INT line)
 {
 #ifdef NO_TRACE_MEM
  return ;
@@ -431,7 +458,8 @@ void dshred_memlist(char* file, int line)
 #endif
 }
 
-void dadd_to_memlist(void* ptr, char* file, int line, int size)
+
+void dadd_to_memlist(void* ptr, CHAR* file, INT line, INT size)
 {
  struct dmem_list* newh;
  sdebug("%s:%d dadd_to_memlist(%p) called from <delegation> %s:%d, bytes: %d",__FILE__,__LINE__,ptr, file,line,size);
@@ -453,10 +481,11 @@ void dadd_to_memlist(void* ptr, char* file, int line, int size)
  newh->file = file;
  newh->line = line;
  newh->count = size;
- dmlist       = newh; 
+ dmlist       = newh;
 }
 
-void dprint_memlist(char* file, int line)
+
+void dprint_memlist(CHAR* file, INT line)
 {
 #ifdef NO_TRACE_MEM
  return ;
@@ -474,7 +503,8 @@ void dprint_memlist(char* file, int line)
 #endif
 }
 
-void ddel_from_memlist(void* ptr, char* file, int line)
+
+void ddel_from_memlist(void* ptr, CHAR* file, INT line)
 {
  struct dmem_list *tmp, *prev;
  sdebug("%s:%d ddel_from_memlist(%p) called from <delegation> %s:%d",__FILE__,__LINE__,ptr,file,line);
