@@ -19,7 +19,7 @@ int main(int lb, char** par)
  PGresult* pgres;
  char*** out;
  int a,b;
- debug("%s:%d pgxtest",__FILE__,__LINE__);
+ debug("%s:%d pgxtest(%d)",__FILE__,__LINE__,lb);
  connection=0;
  pgres=0;
  out=0;
