@@ -13,7 +13,7 @@
 #include "common.h"
 #include "toolbar.h"
 
-static const char * xpm_new[] =
+static const CHAR * xpm_new[] =
 {
 "16 16 3 1",
 "       c None",
@@ -37,7 +37,7 @@ static const char * xpm_new[] =
 "                "
 };
 
-static const char * xpm_open[] =
+static const CHAR * xpm_open[] =
 {
 "16 16 3 1",
 "       c None",
@@ -61,7 +61,7 @@ static const char * xpm_open[] =
 "                ",
 };
 
-static const char * xpm_create[] =
+static const CHAR * xpm_create[] =
 {
 "16 16 2 1",
 "       c None",
@@ -84,7 +84,7 @@ static const char * xpm_create[] =
 "       c        ",
 };
 
-static const char * xpm_copy[] =
+static const CHAR * xpm_copy[] =
 {
 "16 16 2 1",
 "       c None",
@@ -107,7 +107,7 @@ static const char * xpm_copy[] =
 "                ",
 };
 
-static const char * xpm_save[] =
+static const CHAR * xpm_save[] =
 {
 "16 16 2 1",
 "       c None",
@@ -130,7 +130,7 @@ static const char * xpm_save[] =
 "      ccc       ",
 };
 
-static const char * xpm_drop[] =
+static const CHAR * xpm_drop[] =
 {
 "16 16 2 1",
 "       c None",
@@ -153,7 +153,7 @@ static const char * xpm_drop[] =
 "cccc           c",
 };
 
-static const char * xpm_sql[] =
+static const CHAR * xpm_sql[] =
 {
 "16 16 2 1",
 "c      c #000000000000",
@@ -176,7 +176,7 @@ static const char * xpm_sql[] =
 "             cc ",
 };
 
-static const char * xpm_env[] =
+static const CHAR * xpm_env[] =
 {
 "16 16 5 1",
 "       c None",
@@ -202,7 +202,7 @@ static const char * xpm_env[] =
 "                ",
 };
 
-static const char * xpm_fexec1[] =
+static const CHAR * xpm_fexec1[] =
 {
 "16 16 2 1",
 "       c None",
@@ -225,7 +225,7 @@ static const char * xpm_fexec1[] =
 "       ccc      ",
 };
 
-static const char * xpm_fexec2[] =
+static const CHAR * xpm_fexec2[] =
 {
 "16 16 2 1",
 "       c None",
@@ -248,7 +248,7 @@ static const char * xpm_fexec2[] =
 "       ccc      ",
 };
 
-static const char * xpm_fexec3[] =
+static const CHAR * xpm_fexec3[] =
 {
 "16 16 2 1",
 "       c None",
@@ -271,7 +271,7 @@ static const char * xpm_fexec3[] =
 "       ccc      ",
 };
 
-static const char * xpm_about[] =
+static const CHAR * xpm_about[] =
 {
 "16 16 2 1",
 "       c None",
@@ -294,7 +294,7 @@ static const char * xpm_about[] =
 "       ccc      ",
 };
 
-static const char * xpm_btn[] =
+static const CHAR * xpm_btn[] =
 {
 "16 16 4 1",
 "       c None",
@@ -319,7 +319,7 @@ static const char * xpm_btn[] =
 "    cccccccc    ",
 };
 
-static const char * xpm_quit[] =
+static const CHAR * xpm_quit[] =
 {
 "16 16 4 1",
 "       c None",
@@ -344,7 +344,7 @@ static const char * xpm_quit[] =
 "    cccccccc    ",
 };
 
-static const char * xpm_ctable[] =
+static const CHAR * xpm_ctable[] =
 {
 "16 16 4 1",
 "       c None",
@@ -369,7 +369,7 @@ static const char * xpm_ctable[] =
 "                ",
 };
 
-static const char * xpm_dtable[] =
+static const CHAR * xpm_dtable[] =
 {
 "16 16 4 1",
 "       c None",
@@ -394,7 +394,7 @@ static const char * xpm_dtable[] =
 "                ",
 };
 
-static const char * xpm_dview[] =
+static const CHAR * xpm_dview[] =
 {
 "16 16 4 1",
 "       c None",
@@ -419,7 +419,7 @@ static const char * xpm_dview[] =
 "                ",
 };
 
-static const char * xpm_dins[] =
+static const CHAR * xpm_dins[] =
 {
 "16 16 2 1",
 "       c None",
@@ -442,7 +442,7 @@ static const char * xpm_dins[] =
 "cc  cc          ",
 };
 
-static const char * xpm_ddel[] =
+static const CHAR * xpm_ddel[] =
 {
 "16 16 2 1",
 "       c None",
@@ -465,7 +465,7 @@ static const char * xpm_ddel[] =
 "          cc  cc",
 };
 
-static const char * xpm_dwiz[] =
+static const CHAR * xpm_dwiz[] =
 {
 "16 16 2 1",
 "       c None",
@@ -487,12 +487,10 @@ static const char * xpm_dwiz[] =
 "                ",
 "                ",
 };
-
-
 void get_toolbar(GtkWidget* w, GtkWidget **tb);
 void about_window_new();
 
-static char *xpm_big[] =
+static CHAR *xpm_big[] =
 {
 "   210   210       64            1",
 ". c #000100",
@@ -772,7 +770,7 @@ static char *xpm_big[] =
 "666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666666"
 };
 
-int about_clback(GtkWidget* w, gpointer d)
+INT about_clback(GtkWidget* w, gpointer d)
 {
  debug("%s:%d about_clback()", __FILE__,__LINE__);
  gtk_main_quit();
@@ -798,7 +796,7 @@ void about_window_new()
  label = gtk_label_new("written by Morgoth DBMA\n+48693582014\nmorgothdbma@o2.pl");
  button = gtk_button_new();
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (window->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_btn);
+	 (window->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_btn);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_widget_show(pix);
  bhbox = gtk_hbox_new (FALSE, 1);
@@ -811,7 +809,7 @@ void about_window_new()
  table = gtk_table_new (2, 2, FALSE);
  gtk_container_set_border_width(GTK_CONTAINER(table), 5);
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (window->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_big);
+	 (window->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_big);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_widget_show(pix);
  gtk_table_attach (GTK_TABLE (table), pix, 0, 2, 0, 1,
@@ -847,91 +845,84 @@ void get_toolbar(GtkWidget* w, GtkWidget **tb)
  style = gtk_widget_get_style(w);
  gcm = gdk_colormap_get_system();
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_new);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_new);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "New DB", "Private",pix,create_database,NULL);
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_open);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_open);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Open DB", "Private",pix,load_database,NULL);
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_create);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_create);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Create DB from file","Private",pix,create_DB_from_file,NULL);
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_save);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_save);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Save DB to file", "Private",pix,save_database,NULL);
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_copy);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_copy);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Copy DB", "Private",pix,copy_database,NULL);
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_drop);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_drop);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Drop DB", "Private",pix,drop_database,NULL);
  gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_sql);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_sql);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "SQL Query Editor", "Private",pix,query_executor,NULL);
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_env);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_env);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "DB Environment", "Private",pix,env_dialog,NULL);
  gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_fexec1);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_fexec1);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Fast Execute OpenDlg", "Private",pix,execute_fast,(gpointer)(1));
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_fexec2);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_fexec2);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Fast Execute Filename", "Private",pix,execute_fast,(gpointer)(2));
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_fexec3);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_fexec3);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Fast Execute Command", "Private",pix,execute_fast,(gpointer)(3));
  gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_ctable);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_ctable);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Create table wizard", "Private",pix,create_table,NULL);
- 
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_dtable);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_dtable);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Drop table(s)", "Private",pix,tdrop_table,NULL);
- 
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_dview);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_dview);
  pix = gtk_pixmap_new(pix_new, mask);
- gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Drop view(s)", "Private",pix,tdrop_view,NULL); 
- 
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Drop view(s)", "Private",pix,tdrop_view,NULL);
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_dins);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_dins);
  pix = gtk_pixmap_new(pix_new, mask);
- gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Insert", "Private",pix,tinsert,NULL); 
- 
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Insert", "Private",pix,tinsert,NULL);
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_ddel);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_ddel);
  pix = gtk_pixmap_new(pix_new, mask);
- gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Delete", "Private",pix,tdelete,NULL); 
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Delete", "Private",pix,tdelete,NULL);
  gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
- 
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_dwiz);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_dwiz);
  pix = gtk_pixmap_new(pix_new, mask);
- gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Wizards", "Private",pix,wizards,NULL); 
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Wizards", "Private",pix,wizards,NULL);
  gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
- 
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_about);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_about);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "About", "Private",pix,about_box,NULL);
- 
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
-	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_quit);
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(CHAR **)xpm_quit);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Quit", "Private",pix,GTK_SIGNAL_FUNC(menu_quit),NULL);
 }
