@@ -12,16 +12,15 @@
  FILE: toolbar.h */
 #include "common.h"
 #include "wizards.h"
-
 extern PGconn* connection;
-extern int want_all_elems;
+extern INT want_all_elems;
 static struct WizData wdata;
-
-static char* qptr = NULL;
+static CHAR* qptr = NULL;
 static struct PassInsertData pidata;
-static int wizstep = 0;
+static INT wizstep = 0;
+static INT ieditor = 0;
 
-int abort_query(GtkWidget* w, gpointer data)
+INT abort_query(GtkWidget* w, gpointer data)
 {
  debug("%s:%d abort_query()",__FILE__,__LINE__);
  gtk_main_quit();
@@ -30,11 +29,12 @@ int abort_query(GtkWidget* w, gpointer data)
  return FALSE;
 }
 
+
 void update_pidata(GtkWidget* w, gpointer data)
 {
  debug("%s:%d update_pidata()",__FILE__,__LINE__);
- int i;
- int idx = (int)data;
+ INT i;
+ INT idx = (INT)data;
  strcpy(pidata.values[idx], gtk_entry_get_text(GTK_ENTRY(w)));
  for (i=0;i<pidata.n;i++)
  {
@@ -42,12 +42,13 @@ void update_pidata(GtkWidget* w, gpointer data)
  }
 }
 
+
 void update_pidata_combo(GtkWidget* w, gpointer data)
 {
  debug("%s:%d update_pidata_combo()",__FILE__,__LINE__);
- int i;
- int idx = (int)data;
- char* ctext = gtk_entry_get_text(GTK_ENTRY(w));
+ INT i;
+ INT idx = (INT)data;
+ CHAR* ctext = gtk_entry_get_text(GTK_ENTRY(w));
  debug("Combo type is: %s\n", ctext);
  if (!strcmp(ctext,"exactly"))       pidata.types[idx] = DEL_TYPE_EXACTLY;
  else if (!strcmp(ctext,"begins"))   pidata.types[idx] = DEL_TYPE_BEGINS;
@@ -61,25 +62,26 @@ void update_pidata_combo(GtkWidget* w, gpointer data)
  }
 }
 
+
 void generate_delete_query(GtkWidget* w, gpointer data)
 {
  debug("%s:%d generate_delete_query()",__FILE__,__LINE__);
- int nbytes;
- int i,n,x;
- int ins;
- int max;
- char* tmps;
+ INT nbytes;
+ INT i,n,x;
+ INT ins;
+ INT max;
+ CHAR* tmps;
  nbytes = MAX_QUERY_LENGTH;
  n = pidata.n;
  max = 0;
- for (i=0;i<n;i++) 
+ for (i=0;i<n;i++)
  {
 	 x = (strlen(pidata.values[i])+strlen(pidata.names[i])+0x20);
 	 if (x>max) max = x;
 	 nbytes += x;
  }
- tmps = (char*)malloc(2*max+10);
- qptr = (char*)malloc(nbytes);
+ tmps = (CHAR*)malloc(2*max+10);
+ qptr = (CHAR*)malloc(nbytes);
  if (!qptr || !tmps) fatal_here(HERE, "malloc failed");
  sprintf(qptr, "DELETE FROM %s WHERE ", pidata.tabname);
  ins = 0;
@@ -138,7 +140,7 @@ void generate_delete_query(GtkWidget* w, gpointer data)
  }
  if (qptr[strlen(qptr)-2]=='D' && qptr[strlen(qptr)-3]=='N' && qptr[strlen(qptr)-4]=='A')
  {
-  qptr[strlen(qptr)-4] = 0; 
+  qptr[strlen(qptr)-4] = 0;
  }
  debug("QUERY >> '%s'\n", qptr);
  free(tmps);
@@ -146,16 +148,17 @@ void generate_delete_query(GtkWidget* w, gpointer data)
  destroy_widget((GtkWidget*)(data));
 }
 
+
 void generate_insert_query(GtkWidget* w, gpointer data)
 {
  debug("%s:%d generate_insert_query()",__FILE__,__LINE__);
- int nbytes;
- int i,n;
- int ins;
+ INT nbytes;
+ INT i,n;
+ INT ins;
  nbytes = MAX_QUERY_LENGTH;
  n = pidata.n;
  for (i=0;i<n;i++) nbytes += (strlen(pidata.values[i])+10);
- qptr = (char*)malloc(nbytes);
+ qptr = (CHAR*)malloc(nbytes);
  if (!qptr) fatal_here(HERE, "malloc failed");
  sprintf(qptr, "INSERT INTO %s VALUES(", pidata.tabname);
  ins = 0;
@@ -209,9 +212,10 @@ void generate_insert_query(GtkWidget* w, gpointer data)
  destroy_widget((GtkWidget*)(data));
 }
 
+
 void free_pidata()
 {
- int x,i;
+ INT x,i;
  debug("%s:%d free_pixdata()", __FILE__,__LINE__);
  x = pidata.n;
  for (i=0;i<x;i++)
@@ -225,12 +229,13 @@ void free_pidata()
  free(pidata.types);
 }
 
-char* insert_wizard(char* tabname)
+
+CHAR* insert_wizard(CHAR* tabname)
 {
- char*** ptr;
- int row,col;
- char errstr[MAX_QUERY_LENGTH+100];
- int i;
+ CHAR*** ptr;
+ INT row,col;
+ CHAR errstr[MAX_QUERY_LENGTH+100];
+ INT i;
  GtkWidget* window, *table, *entry, *button, *label, *scroller_view, *vbox;
  debug("%s:%d insert_wizard(%s)",__FILE__,__LINE__,tabname?tabname:"null");
  if (!connection) error("no_connection %s:%d", __FILE__,__LINE__);
@@ -250,18 +255,18 @@ char* insert_wizard(char* tabname)
  gtk_container_set_border_width(GTK_CONTAINER(window), 5);
  table = gtk_table_new(2, col, FALSE);
  pidata.n = col;
- pidata.types  = (int*)malloc(col*sizeof(int));
- pidata.names  = (char**)malloc(col*sizeof(char*));
- pidata.values = (char**)malloc(col*sizeof(char*));
- pidata.tabname = (char*)malloc(strlen(tabname)+1);
+ pidata.types  = (INT*)malloc(col*sizeof(INT));
+ pidata.names  = (CHAR**)malloc(col*sizeof(CHAR*));
+ pidata.values = (CHAR**)malloc(col*sizeof(CHAR*));
+ pidata.tabname = (CHAR*)malloc(strlen(tabname)+1);
  if (!pidata.names || !pidata.values || !pidata.tabname) fatal_here(HERE, "malloc failed.");
  strcpy(pidata.tabname, tabname);
  for (i=0;i<col;i++)
  {
-  pidata.names[i] = (char*)malloc(strlen(ptr[0][i])+1);
+  pidata.names[i] = (CHAR*)malloc(strlen(ptr[0][i])+1);
   if (!pidata.names[i]) fatal_here(HERE, "malloc failed");
   strcpy(pidata.names[i], ptr[0][i]);
-  pidata.values[i] = (char*)malloc(MAX_INSERT_STR_LENGTH+1);
+  pidata.values[i] = (CHAR*)malloc(MAX_INSERT_STR_LENGTH+1);
   if (!pidata.values[i]) fatal_here(HERE, "malloc failed");
   strcpy(pidata.values[i], "");
   pidata.types[i] = -1;
@@ -278,7 +283,7 @@ char* insert_wizard(char* tabname)
   gtk_table_attach(GTK_TABLE (table), entry, 1, 2, i, i+1,
 		      GTK_FILL,GTK_FILL, 0, 0);
   gtk_widget_show(entry);
- } 
+ }
  gtk_widget_show(table);
  scroller_view = gtk_scrolled_window_new(NULL,NULL);
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroller_view), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -308,12 +313,13 @@ char* insert_wizard(char* tabname)
  return qptr;
 }
 
-char* delete_wizard(char* tabname)
+
+CHAR* delete_wizard(CHAR* tabname)
 {
- char*** ptr;
- int row,col;
- char errstr[MAX_QUERY_LENGTH+100];
- int i;
+ CHAR*** ptr;
+ INT row,col;
+ CHAR errstr[MAX_QUERY_LENGTH+100];
+ INT i;
  GtkWidget* window, *table, *entry, *button, *label, *scroller_view, *vbox, *combo;
  GList* list;
  debug("%s:%d delete_wizard(%s)",__FILE__,__LINE__,tabname?tabname:"null");
@@ -328,24 +334,29 @@ char* delete_wizard(char* tabname)
     gtk_dialog_printf_big("Error getting table attributes:\nReturn from DBMS: %s\n", errstr);
     return NULL;
    }
+ if (row==1 || col==0)
+   {
+    gtk_dialog_printf("Nothing to delete!");
+    return NULL;
+   }
  //
  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_usize(GTK_WIDGET(window), 450, 400);
  gtk_container_set_border_width(GTK_CONTAINER(window), 5);
  table = gtk_table_new(3, col, FALSE);
  pidata.n = col;
- pidata.types  = (int*)malloc(col*sizeof(int));
- pidata.names  = (char**)malloc(col*sizeof(char*));
- pidata.values = (char**)malloc(col*sizeof(char*));
- pidata.tabname = (char*)malloc(strlen(tabname)+1);
+ pidata.types  = (INT*)malloc(col*sizeof(INT));
+ pidata.names  = (CHAR**)malloc(col*sizeof(CHAR*));
+ pidata.values = (CHAR**)malloc(col*sizeof(CHAR*));
+ pidata.tabname = (CHAR*)malloc(strlen(tabname)+1);
  if (!pidata.names || !pidata.values || !pidata.tabname) fatal_here(HERE, "malloc failed.");
  strcpy(pidata.tabname, tabname);
  for (i=0;i<col;i++)
  {
-  pidata.names[i] = (char*)malloc(strlen(ptr[0][i])+1);
+  pidata.names[i] = (CHAR*)malloc(strlen(ptr[0][i])+1);
   if (!pidata.names[i]) fatal_here(HERE, "malloc failed");
   strcpy(pidata.names[i], ptr[0][i]);
-  pidata.values[i] = (char*)malloc(MAX_INSERT_STR_LENGTH+1);
+  pidata.values[i] = (CHAR*)malloc(MAX_INSERT_STR_LENGTH+1);
   if (!pidata.values[i]) fatal_here(HERE, "malloc failed");
   strcpy(pidata.values[i], "");
   pidata.types[i] = DEL_TYPE_NONE;
@@ -356,14 +367,12 @@ char* delete_wizard(char* tabname)
   gtk_table_attach(GTK_TABLE (table), label, 0, 1, i, i+1,
 		      GTK_FILL,GTK_FILL, 0, 0);
   gtk_widget_show(label);
-  
   entry = gtk_entry_new();
   gtk_entry_set_max_length(GTK_ENTRY(entry), MAX_INSERT_STR_LENGTH);
   gtk_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(update_pidata),(gpointer)(i));
   gtk_table_attach(GTK_TABLE (table), entry, 1, 2, i, i+1,
 		      GTK_FILL,GTK_FILL, 0, 0);
   gtk_widget_show(entry);
-  
   list = NULL;
   list = g_list_append(list, "none");
   list = g_list_append(list, "exactly");
@@ -379,7 +388,7 @@ char* delete_wizard(char* tabname)
 		      GTK_FILL,GTK_FILL, 0, 0);
   gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry), "changed", GTK_SIGNAL_FUNC(update_pidata_combo),(gpointer)(i));
   gtk_widget_show(combo);
- } 
+ }
  gtk_widget_show(table);
  scroller_view = gtk_scrolled_window_new(NULL,NULL);
  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroller_view), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -409,7 +418,8 @@ char* delete_wizard(char* tabname)
  return qptr;
 }
 
-gint delete_combos_proc_wiz(GtkWidget* w, gpointer d)
+
+INT delete_combos_proc_wiz(GtkWidget* w, gpointer d)
 {
  debug("%s:%d delete_combos_proc_wiz()",__FILE__,__LINE__);
  gtk_main_quit();
@@ -418,6 +428,7 @@ gint delete_combos_proc_wiz(GtkWidget* w, gpointer d)
  return TRUE;
 }
 
+
 void ok_combo_proc_wiz(GtkWidget* w, gpointer cmb)
 {
  debug("%s:%d ok_combo_proc_wiz()",__FILE__,__LINE__);
@@ -426,14 +437,15 @@ void ok_combo_proc_wiz(GtkWidget* w, gpointer cmb)
  gtk_main_quit();
 }
 
-int setup_combo_views(PGconn* c, GtkWidget* w, GtkWidget** cmb)
+
+INT setup_combo_views(PGconn* c, GtkWidget* w, GtkWidget** cmb)
 {
- char errstr[MAX_QUERY_LENGTH];
+ CHAR errstr[MAX_QUERY_LENGTH];
  debug("%s:%d setup_combo_views()", __FILE__,__LINE__);
- int row,col,i;
- char*** ptr;
- char* tmps;
- char first[MAX_TABLE_NAME*2+4];
+ INT row,col,i;
+ CHAR*** ptr;
+ CHAR* tmps;
+ CHAR first[MAX_TABLE_NAME*2+4];
  GList* list;
  list = NULL;
  debug("%s:%d setup_combo",__FILE__,__LINE__);
@@ -459,9 +471,9 @@ int setup_combo_views(PGconn* c, GtkWidget* w, GtkWidget** cmb)
   cmb=NULL;
   return -1;
  }
- for (i=0;i<row;i++) 
+ for (i=0;i<row;i++)
  {
-	 tmps = (char*)malloc(strlen(ptr[i][0])+strlen(ptr[i][0])+4);
+	 tmps = (CHAR*)malloc(strlen(ptr[i][0])+strlen(ptr[i][0])+4);
 	 if (!tmps) fatal_here(HERE, "malloc failed");
 	 strcpy(tmps, ptr[i][0]);
 	 strcat(tmps,".");
@@ -481,12 +493,13 @@ int setup_combo_views(PGconn* c, GtkWidget* w, GtkWidget** cmb)
  return 0;
 }
 
-int setup_combo_tables(PGconn* c, GtkWidget* w, GtkWidget** cmb, int all_opt)
+
+INT setup_combo_tables(PGconn* c, GtkWidget* w, GtkWidget** cmb, INT all_opt)
 {
- char errstr[MAX_QUERY_LENGTH];
+ CHAR errstr[MAX_QUERY_LENGTH];
  debug("%s:%d setup_combo_tables(%d)", __FILE__,__LINE__, all_opt);
- int row,col,i;
- char*** ptr;
+ INT row,col,i;
+ CHAR*** ptr;
  GList* list;
  list = NULL;
  debug("%s:%d setup_combo",__FILE__,__LINE__);
@@ -522,10 +535,10 @@ int setup_combo_tables(PGconn* c, GtkWidget* w, GtkWidget** cmb, int all_opt)
 }
 
 
-char* select_table_wizard(int all_opt)
+CHAR* select_table_wizard(INT all_opt)
 {
  GtkWidget* dialog, *combo, *button, *label;
- qptr = (char*)malloc(MAX_TABLE_NAME+1);
+ qptr = (CHAR*)malloc(MAX_TABLE_NAME+1);
  if (!qptr) fatal_here(HERE, "malloc failed");
  debug("%s:%d select_table_wizard(%d)",__FILE__,__LINE__,all_opt);
  if (!connection) error("select_table_wizard: %s:%d", __FILE__,__LINE__);
@@ -538,7 +551,7 @@ char* select_table_wizard(int all_opt)
  gtk_widget_show(label);
  button = gtk_button_new_with_label("Select");
  combo=NULL;
- if (setup_combo_tables(connection, dialog, &combo, all_opt)==-1) 
+ if (setup_combo_tables(connection, dialog, &combo, all_opt)==-1)
  {
 	 free(qptr);
 	 qptr = NULL;
@@ -558,10 +571,11 @@ char* select_table_wizard(int all_opt)
  return qptr;
 }
 
-char* select_view_wizard()
+
+CHAR* select_view_wizard()
 {
  GtkWidget* dialog, *combo, *button, *label;
- qptr = (char*)malloc(MAX_TABLE_NAME+1);
+ qptr = (CHAR*)malloc(MAX_TABLE_NAME+1);
  if (!qptr) fatal_here(HERE, "malloc failed");
  debug("%s:%d select_view_wizard()",__FILE__,__LINE__);
  if (!connection) error("select_view_wizard: %s:%d", __FILE__,__LINE__);
@@ -595,14 +609,15 @@ char* select_view_wizard()
 }
 
 
-int gtk_scale_get_value(GtkWidget* w, gpointer ptr)	//SIZEOF(GFLOAT) CAN BE MORE THAN SIZEOF(GPOINTER)
+INT gtk_scale_get_value(GtkWidget* w, gpointer ptr)	//SIZEOF(GFLOAT) CAN BE MORE THAN SIZEOF(GPOINTER)
 {
  GtkAdjustment* adj;
  debug("%s:%d gtk_scale_get_value()",__FILE__,__LINE__);
  adj = gtk_range_get_adjustment(GTK_RANGE(&(GTK_SCALE(ptr)->range)));
- return (int)(adj->value);
+ return (INT)(adj->value);
 }
 
+
 void gtk_scale_set_value(GtkWidget* scale, gfloat val)
 {
  debug("%s:%d gtk_scale_set_value(%f)",__FILE__,__LINE__,val);
@@ -612,11 +627,12 @@ void gtk_scale_set_value(GtkWidget* scale, gfloat val)
  gtk_range_set_adjustment(GTK_RANGE(&(GTK_SCALE(scale)->range)), GTK_ADJUSTMENT(adj));
 }
 
+
 void scale_changed_func(GtkWidget* scale, gfloat dummy)
 {
  debug("%s:%d scale_changed_func()",__FILE__,__LINE__);
  GtkWidget* label;
- int val = gtk_scale_get_value(wdata.scale, wdata.scale);
+ INT val = gtk_scale_get_value(wdata.scale, wdata.scale);
  if (val)
    {
     gtk_widget_destroy(wdata.label2);
@@ -625,6 +641,7 @@ void scale_changed_func(GtkWidget* scale, gfloat dummy)
     gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
     gtk_widget_show(label);
     gtk_table_attach(GTK_TABLE(wdata.table), label, 0, 50, 0, 30, GTK_FILL|GTK_EXPAND,GTK_FILL|GTK_EXPAND, 0, 0);
+    ieditor = 0;
    }
  else
    {
@@ -634,17 +651,57 @@ void scale_changed_func(GtkWidget* scale, gfloat dummy)
     gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
     gtk_widget_show(label);
     gtk_table_attach(GTK_TABLE(wdata.table), label, 0, 50, 0, 30, GTK_FILL|GTK_EXPAND,GTK_FILL|GTK_EXPAND, 0, 0);
+    ieditor = 1;
    }
 }
 
+
+void setup_txtscene(GtkWidget* table)
+{
+ GtkWidget* text, *hscrollbar, *vscrollbar, *button[2];
+ debug("%s:%d setup_txtscene()",__FILE__,__LINE__);
+ text = gtk_text_new(NULL, NULL);
+ gtk_table_attach(GTK_TABLE(table), text, 0, 40, 10, 40,
+		      GTK_FILL | GTK_EXPAND,
+		      GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
+ gtk_text_set_editable(GTK_TEXT(text), TRUE);
+ gtk_text_set_word_wrap(GTK_TEXT(text), TRUE);
+ gtk_text_set_line_wrap(GTK_TEXT(text), TRUE);
+ gtk_widget_show(text);
+ hscrollbar = gtk_hscrollbar_new(GTK_TEXT (text)->hadj);
+ gtk_table_attach(GTK_TABLE(table), hscrollbar, 0, 40, 40, 50,
+		      GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+ gtk_widget_show(hscrollbar);
+ vscrollbar = gtk_vscrollbar_new(GTK_TEXT (text)->vadj);
+ gtk_table_attach (GTK_TABLE (table), vscrollbar, 40, 50, 10, 40,
+		      GTK_FILL, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0);
+ gtk_widget_show(vscrollbar);
+ button[0] = gtk_button_new_with_label("Load");
+ button[1] = gtk_button_new_with_label("Save");
+ gtk_table_attach(GTK_TABLE(table), button[0], 0, 20, 0, 10, GTK_FILL, GTK_FILL, 0, 0);
+ gtk_table_attach(GTK_TABLE(table), button[1], 20,40, 0, 10, GTK_FILL, GTK_FILL, 0, 0);
+ gtk_widget_show(button[0]);
+ gtk_widget_show(button[1]);
+ gtk_widget_grab_focus(text);
+ gtk_signal_connect(GTK_OBJECT(button[0]), "clicked", GTK_SIGNAL_FUNC(load_proc), (gpointer)(text));
+ gtk_signal_connect(GTK_OBJECT(button[1]), "clicked", GTK_SIGNAL_FUNC(save_proc), (gpointer)(text));
+ wdata.text = text;
+ wdata.load = button[0];
+ wdata.save = button[1];
+ wdata.hscrl = hscrollbar;
+ wdata.vscrl = vscrollbar;
+}
+
+
 void prev_ctable_func(GtkWidget* w, gpointer data)
 {
  debug("%s:%d prev_ctable_func()", __FILE__,__LINE__);
  GtkWidget* tab = *((GtkWidget**)(data));
- GtkWidget* label;
+ GtkWidget* label, *scale;
+ GtkObject *adj;
  switch (wizstep)
  {
-  case 0:
+  case 0:	/* 0 --> abort */
   	if (gtk_dialog_yes_no_printf("Going back at first step\nmeans closing Wizard. OK?"))
    	  {
     	   qptr = NULL;
@@ -652,10 +709,11 @@ void prev_ctable_func(GtkWidget* w, gpointer data)
            return;
    	  }
 	break;
-  case 1:
+  case 1:	/* 1 --> 0 */
 	    gtk_widget_destroy(wdata.label2);
 	    wdata.ncols = gtk_scale_get_value(wdata.scale, wdata.scale);
 	    gtk_widget_destroy(wdata.scale);
+	    if (wdata.ncols>0) ieditor = 0;
  	    label = gtk_label_new("Welcome to Create Table Wizard\nthis wizard will guide You\nthrough the rest of Create Table process\nGood luck!");
  	    gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_FILL);
 	    gtk_table_attach(GTK_TABLE(tab), label, 0, 50, 0, 50, GTK_FILL,GTK_FILL, 0, 0);
@@ -663,7 +721,34 @@ void prev_ctable_func(GtkWidget* w, gpointer data)
             wdata.label = label;
 	    wizstep--;
 	    break;
-  default:
+  case 2:	/* 2 -->  1 */
+	    if (ieditor)
+	      {
+               gtk_widget_destroy(wdata.text);
+               gtk_widget_destroy(wdata.save);
+               gtk_widget_destroy(wdata.load);
+               gtk_widget_destroy(wdata.hscrl);
+               gtk_widget_destroy(wdata.vscrl);
+	      }
+ 	    adj = gtk_adjustment_new(0.0,0.0,49.0, 1.0, 1.0, 1.0);
+	    scale = gtk_hscale_new(GTK_ADJUSTMENT(adj));
+	    gtk_scale_set_digits(GTK_SCALE(scale), 0);
+	    gtk_scale_set_value(scale, (gfloat)wdata.ncols);
+	    gtk_scale_set_draw_value(GTK_SCALE(scale), TRUE);
+	    gtk_scale_set_value(scale, (gfloat)(wdata.ncols));
+	    gtk_widget_show(scale);
+	    wdata.scale = scale;
+ 	    gtk_table_attach(GTK_TABLE(tab), scale, 0, 50, 30, 50, GTK_FILL,GTK_FILL|GTK_EXPAND, 0, 0);
+ 	    label = gtk_label_new("Select number of columns (1-48):\nSelect 0 if you want to\nLoad prepared table from file");
+	    wdata.label2 = label;
+ 	    gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
+ 	    gtk_table_attach(GTK_TABLE(tab), label, 0, 50, 0, 30, GTK_FILL|GTK_EXPAND,GTK_FILL|GTK_EXPAND, 0, 0);
+	    gtk_widget_show(label);
+	    gtk_widget_show(tab);
+ 	    gtk_signal_connect(GTK_OBJECT(adj), "value_changed", GTK_SIGNAL_FUNC(scale_changed_func), NULL);
+	    wizstep--;
+	    break;
+  default:	/* other */
 	    gtk_dialog_printf("Not implemented!");
 	    qptr = NULL;
 	    gtk_main_quit();
@@ -680,7 +765,7 @@ void next_ctable_func(GtkWidget* w, gpointer data)
  GtkWidget* tab = *((GtkWidget**)(data));
  switch (wizstep)
    {
-    case 0:
+    case 0:	/* 0 --> 1 */
 	    gtk_widget_destroy(wdata.label);
  	    adj = gtk_adjustment_new(0.0,0.0,49.0, 1.0, 1.0, 1.0);
 	    scale = gtk_hscale_new(GTK_ADJUSTMENT(adj));
@@ -700,7 +785,71 @@ void next_ctable_func(GtkWidget* w, gpointer data)
  	    gtk_signal_connect(GTK_OBJECT(adj), "value_changed", GTK_SIGNAL_FUNC(scale_changed_func), NULL);
 	    wizstep++;
 	    break;
-    default:
+    case 1:	/* 1 --> 2 */
+	    wdata.ncols = gtk_scale_get_value(wdata.scale, wdata.scale);
+	    gtk_widget_destroy(wdata.label2);
+	    gtk_widget_destroy(wdata.scale);
+	    if (wdata.ncols == 0)
+	      {
+	       setup_txtscene(tab);
+	       wizstep++;
+	       ieditor = 1;
+	       gtk_widget_show(tab);
+	       break;
+	      }
+	    gtk_widget_show(tab);
+	    wizstep++;
+	    break;
+    case 2:	/* currently ready for load/save options */
+	    if (ieditor)
+	      {
+		INT l,i;
+		CHAR* tmp;
+ 		l = gtk_text_get_length(GTK_TEXT(wdata.text));
+		if (l > MAX_QUERY_LENGTH-10)
+		  {
+                   gtk_dialog_printf("Query is too long!");
+		   break;
+		  }
+ 		if (l<3)
+    		  {
+		   gtk_dialog_printf("Will not execute empty query");
+		   break;
+		  }
+		 qptr = malloc(l+2);
+		 for (i=0;i<l;i++) qptr[i] = GTK_TEXT_INDEX(GTK_TEXT(wdata.text), i);
+		 qptr[i] = 0;
+		 tmp = malloc(strlen(qptr)+1);
+		 strcpy(tmp, qptr);
+		 downcase(tmp);
+		 if (!strstr(tmp,"create table"))
+		   {
+		    gtk_dialog_printf("CREATE TABLE QUERY must contain\n\"CREATE TABLE\" statement");
+                    free(qptr);
+		    qptr = NULL;
+		    free(tmp);
+		    break;
+		   }
+		 free(tmp);
+  	         if (gtk_dialog_yes_no("Do you want to save wizard query?"))
+	           {
+		    save_proc(NULL, (gpointer)wdata.text);
+	           }
+                 gtk_widget_destroy(wdata.text);
+                 gtk_widget_destroy(wdata.save);
+                 gtk_widget_destroy(wdata.load);
+                 gtk_widget_destroy(wdata.hscrl);
+                 gtk_widget_destroy(wdata.vscrl);
+	         wizstep++;
+	         gtk_main_quit();
+		 break;
+	      }
+	    /* HERE CASE WHEN USER WANTS TO CREATE COLUMNS */
+	    gtk_dialog_printf("Not implemented!");
+	    qptr = NULL;
+	    gtk_main_quit();
+	    break;
+    default:	/* other - finish? */
 	    gtk_dialog_printf("Not implemented!");
 	    qptr = NULL;
 	    gtk_main_quit();
@@ -708,14 +857,18 @@ void next_ctable_func(GtkWidget* w, gpointer data)
    }
 }
 
+
 void init_wdata()
 {
  debug("%s:%d init_wdata()", __FILE__,__LINE__);
+ ieditor = 0;
  wdata.ncols = 4;
- wdata.label = wdata.label2 = wdata.scale = wdata.table = NULL;
+ wdata.label = wdata.label2 = wdata.scale = wdata.table =
+ wdata.text  = wdata.load   = wdata.save  = wdata.hscrl = wdata.vscrl = NULL;
 }
 
-char* ctable_wizard()
+
+CHAR* ctable_wizard()
 {
  debug("%s:%d ctable_wizard()", __FILE__,__LINE__);
  if (qptr) free(qptr);
