@@ -13,37 +13,36 @@
 #ifndef __MORGOTHDBMA_WIZARDS_H__
 #define __MORGOTHDBMA_WIZARDS_H__
 #include "main.h"
-
 #define DEL_TYPE_EXACTLY	0
 #define DEL_TYPE_BEGINS		1
 #define DEL_TYPE_ENDS		2
 #define DEL_TYPE_CONTAINS	3
 #define DEL_TYPE_NONE   	4
-
 #define MAX_TABLE_NAME	     2048
-
 struct PassInsertData
 {
- char* tabname;
- int n;
- char** names;
- char** values;
- int*   types;
+ CHAR* tabname;
+ INT n;
+ CHAR** names;
+ CHAR** values;
+ INT*   types;
 };
-
 struct WizData
 {
  GtkWidget* label;
  GtkWidget* label2;
  GtkWidget* scale;
  GtkWidget* table;
- int ncols;
+ GtkWidget* load;
+ GtkWidget* save;
+ GtkWidget* vscrl;
+ GtkWidget* hscrl;
+ GtkWidget* text;
+ INT ncols;
 };
-
-char* insert_wizard(char* tabname);
-char* delete_wizard(char* tabname);
-char* select_table_wizard(int all_opt);
-char* select_view_wizard();
-char* ctable_wizard();
-
+CHAR* insert_wizard(CHAR* tabname);
+CHAR* delete_wizard(CHAR* tabname);
+CHAR* select_table_wizard(INT all_opt);
+CHAR* select_view_wizard();
+CHAR* ctable_wizard();
 #endif
